==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Gebruiker gedefinieerde eigenschap toevoegen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Waarde:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translation>*VARIEERT*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Geen selectie</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Specifieke eigenschappen</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Afhankelijke objecten</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Gebruiker gedefinieerd</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Eigenschap van geselecteerde objecten verwijderen</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Gebruiker gedefinieerde eigenschap aan geselecteerde objecten toevoegen</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Eigenschappen-editor</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Selectie:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Algemeene eigenschappen</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Lijntype schaal:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Beschermd:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Handle:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Z-coördinaat tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Eigenschappen van het huidige blok en de huidige laag weergeven</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Gebruiker gedefinieerde eigenschap toevoegen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Waarde:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translation>*VARIEERT*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translation>Geen selectie</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Specifieke eigenschappen</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Afhankelijke objecten</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Gebruiker gedefinieerd</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Eigenschap van geselecteerde objecten verwijderen</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Gebruiker gedefinieerde eigenschap aan geselecteerde objecten toevoegen</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Show</source>
        <translation>Tonen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation>Toon alle eigenschappen</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <location line="+336"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Eigenschappen-editor</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Selectie:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Algemeene eigenschappen</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Lijntype schaal:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Beschermd:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Handle:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Z-coördinaat tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Eigenschappen van het huidige blok en de huidige laag weergeven</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation>Toevoegen van gebruiker gedefinieerde eigenschappen toestaan</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation>Toon altijd alle eigenschappen (dit kan de selectie van objecten vertragen)</translation>
    </message>
</context>
</TS>
